template: home

another link | another link | another link | another link

# ORANGE_SUNSET

# latest news

## 01.09.2006

This is where you can put your latest news.

read more ...

## 01.09.2006

This is where you can put your latest news.

read more ...

# additional links

- open designs
- learn XHTML
- learn CSS
- get firefox

# other information

This space can be used for additional information such as a contact phone number, address or maybe even a graphic.

# introduction

This standards compliant website template is a themed version of the previously released 'turn_it_up' design. It is released as an 'open source' design (under the Creative Commons Attribution 2.5 Licence), which means that you are free to download and use it for anything you want (including modifying and amending it). The logo image is from a digital photograph taken by me, so there are no issues with copyright there. All I ask is that you leave the 'design by dcarter' link in the footer of the template, but other than that...

This template is written entirely in XHTML 1.1 and CSS, and can be validated using the links in the footer.

You can view my other 'open source' template designs here.

# example elements

Here are some example elements available with this template.

## Bold Text

this is an example of bold text

## Italics

this is an example of italic text

## Links

this is an example link

## Block Quotes

> Some blockquote text. Lorem ipsum dolor sit amet, consectetur adipisicing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua.

## Unordered Lists

- list item 1
- list item 2

## Ordered Lists

1. list item 1
2. list item 2

## Images

images can be placed on the left, in the center or on the right.

Lorem ipsum dolor sit amet, consectetur adipisicing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua. Ut enim ad minim veniam, quis nostrud exercitation ullamco laboris nisi ut aliquip ex ea commodo consequat. Duis aute irure dolor in reprehenderit in voluptate velit esse cillum dolore eu fugiat nulla pariatur.

Lorem ipsum dolor sit amet, consectetur adipisicing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua. Ut enim ad minim veniam, quis nostrud exercitation ullamco laboris nisi ut aliquip ex ea commodo consequat. Duis aute irure dolor in reprehenderit in voluptate velit esse cillum dolore eu fugiat nulla pariatur.